==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/client/mixin/MouseMixin.java <==
package com.zurrtum.create.client.mixin;

import com.llamalad7.mixinextras.sugar.Local;
import com.zurrtum.create.client.Create;
import com.zurrtum.create.client.content.contraptions.elevator.ElevatorControlsHandler;
import com.zurrtum.create.client.content.trains.TrainHUD;
import net.minecraft.class_310;
import net.minecraft.class_312;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_312.class)
public class MouseMixin {
    @Shadow
    @Final
    private class_310 client;

    @Inject(method = "onMouseButton(JIII)V", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/MinecraftClient;getOverlay()Lnet/minecraft/client/gui/screen/Overlay;", ordinal = 0), cancellable = true)
    private void onMouseButton(long window, int button, int action, int mods, CallbackInfo ci) {
        if (action == 0) {
            return;
        }
        if (Create.SCHEMATIC_HANDLER.onMouseInput(client, button) || Create.SCHEMATIC_AND_QUILL_HANDLER.onMouseInput(client, button)) {
            ci.cancel();
        }
    }

    @Inject(method = "onMouseScroll(JDD)V", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/network/ClientPlayerEntity;getInventory()Lnet/minecraft/entity/player/PlayerInventory;"), cancellable = true)
    private void onMouseScroll(long window, double horizontal, double vertical, CallbackInfo ci, @Local(ordinal = 4) double delta) {
        if (Create.SCHEMATIC_HANDLER.mouseScrolled(delta) || Create.SCHEMATIC_AND_QUILL_HANDLER.mouseScrolled(client, delta) || TrainHUD.onScroll(
            delta) || ElevatorControlsHandler.onScroll(client, delta)) {
            ci.cancel();
        }
    }
}

==> create-fly-1.21.10-6.0.8-3-sources.jar: com/zurrtum/create/client/mixin/MouseMixin.java <==
package com.zurrtum.create.client.mixin;

import com.llamalad7.mixinextras.sugar.Local;
import com.zurrtum.create.client.Create;
import com.zurrtum.create.client.content.contraptions.elevator.ElevatorControlsHandler;
import com.zurrtum.create.client.content.trains.TrainHUD;
import net.minecraft.class_11910;
import net.minecraft.class_310;
import net.minecraft.class_312;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_312.class)
public class MouseMixin {
    @Shadow
    @Final
    private class_310 client;

    @Inject(method = "onMouseButton(JLnet/minecraft/client/input/MouseInput;I)V", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/MinecraftClient;getOverlay()Lnet/minecraft/client/gui/screen/Overlay;", ordinal = 0), cancellable = true)
    private void onMouseButton(long window, class_11910 input, int action, CallbackInfo ci) {
        if (action == 0) {
            return;
        }
        int button = input.comp_4801();
        if (Create.SCHEMATIC_HANDLER.onMouseInput(client, button) || Create.SCHEMATIC_AND_QUILL_HANDLER.onMouseInput(client, button)) {
            ci.cancel();
        }
    }

    @Inject(method = "onMouseScroll(JDD)V", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/network/ClientPlayerEntity;getInventory()Lnet/minecraft/entity/player/PlayerInventory;"), cancellable = true)
    private void onMouseScroll(long window, double horizontal, double vertical, CallbackInfo ci, @Local(ordinal = 4) double delta) {
        if (Create.SCHEMATIC_HANDLER.mouseScrolled(delta) || Create.SCHEMATIC_AND_QUILL_HANDLER.mouseScrolled(client, delta) || TrainHUD.onScroll(
            delta) || ElevatorControlsHandler.onScroll(client, delta)) {
            ci.cancel();
        }
    }
}
